@@ -19,7 +19,7 @@
 #ifdef _DEFINE
 # define EXTERN
 # define INIT(x)	= x
-SM_IDSTR(MilterlId, "@(#)$Id: libmilter.h,v 8.33.2.13 2003/10/20 21:51:50 msk Exp $")
+SM_IDSTR(MilterlId, "@(#)$Id: libmilter.h,v 8.50 2003/12/11 18:14:34 ca Exp $")
 #else /* _DEFINE */
 # define EXTERN extern
 # define INIT(x)
@@ -49,7 +49,7 @@ typedef pthread_mutex_t smutex_t;
 # define smutex_unlock(mp)	(pthread_mutex_unlock(mp) == 0)
 # define smutex_trylock(mp)	(pthread_mutex_trylock(mp) == 0)
 
-#if _FFR_USE_POLL
+#if SM_CONF_POLL
 
 # include <poll.h>
 # define MI_POLLSELECT  "poll"
@@ -86,7 +86,7 @@ typedef pthread_mutex_t smutex_t;
 # define FD_RD_READY(sd, rds, excs, timeout)	\
 		poll(&(rds), 1, MI_MS(timeout))
 
-#else /* _FFR_USE_POLL */
+#else /* SM_CONF_POLL */
 
 # include <sm/fdset.h>
 # define MI_POLLSELECT  "select"
@@ -113,7 +113,7 @@ typedef pthread_mutex_t smutex_t;
 # define FD_RD_READY(sd, rds, excs, timeout)	\
 		select((sd) + 1, &(rds), NULL, &(excs), (timeout))
 
-#endif /* _FFR_USE_POLL */
+#endif /* SM_CONF_POLL */
 
 #include <sys/time.h>
 
